@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2003, 2004  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -19,18 +19,14 @@
  *
  */
 
+#include "internal.h"
+
 /* Get i18n. */
 #include <gettext.h>
 #define _(String) dgettext (PACKAGE, String)
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
 
-/* Get strlen. */
-#include <string.h>
-
-/* Get xmalloc etc. */
-#include "xalloc.h"
-
 /* _gss_find_mech */
 #include "meta.h"
 
